pub struct VarIntKmer<T: PrimInt + FromPrimitive + IntHelp, KS: KmerSize> {
pub storage: T,
pub phantom: PhantomData<KS>,
}Expand description
A fixed-length Kmer sequence that may not fill the bits of T
side: L R bases: 0 0 0 A C G T T bits: H …….. L bit : 14 12 10 8 6 4 2 0
sorting the integer will give a lexicographic sorting of the corresponding string.
kmers that don’t fill storage are always aligned to the least signifcant bits
Fields
storage: Tphantom: PhantomData<KS>Implementations
Sourceimpl<T: PrimInt + FromPrimitive + Hash + IntHelp, KS: KmerSize> VarIntKmer<T, KS>
impl<T: PrimInt + FromPrimitive + Hash + IntHelp, KS: KmerSize> VarIntKmer<T, KS>